Module hex_conservative::buf_encoder
source · Expand description
Implements a buffered encoder.
This is a low-level module, most uses should be satisfied by the display module instead.
The main type of this module is BufEncoder which provides buffered hex encoding. Such is
faster than the usual write!(f, "{02x}", b)? in a for loop because it reduces dynamic
dispatch and decreases the number of allocations if a String is being created.
Structs
- Hex-encodes bytes into the provided buffer.
- A byte buffer that can only be written-into.
Traits
- Trait for types that can be soundly converted to
OutBytes. - A buffer with compile-time-known length.