pub struct HexWriter<T> { /* private fields */ }Available on crate feature
std only.Expand description
Given a T: fmt::Write, HexWriter implements std::io::Write
and writes the source bytes to its inner T as hex characters.
Implementations
Sourceimpl<T> HexWriter<T>
impl<T> HexWriter<T>
Sourcepub fn new(dest: T, case: Case) -> Self
pub fn new(dest: T, case: Case) -> Self
Creates a HexWriter that writes the source bytes to dest as hex characters
in the given case.
Note even though we take ownership of the writer one can also call this with &mut dest.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes this HexWriter returning the inner T.