docs.rs failed to build hex-conservative-0.2.3
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
hex-conservative-1.3.0
Bitcoin Hexadecimal Library
General purpose hex encoding/decoding library with a conservative MSRV and dependency policy.
Minimum Supported Rust Version (MSRV)
This library should compile with almost any combination of features on Rust 1.56.1, however we
reserve the right to use features to guard compiler specific code so --all-features may not work
using the MSRV toolchain.
Githooks
To assist devs in catching errors before running CI we provide some githooks. If you do not already have locally configured githooks you can use the ones in this repository by running, in the root directory of the repository:
git config --local core.hooksPath githooks/
Alternatively add symlinks in your .git/hooks directory to any of the githooks we provide.