BufEncoder

Struct BufEncoder 

pub struct BufEncoder<const CAP: usize> { /* private fields */ }
Hex-encodes bytes into the provided buffer.

This is an important building block for fast hex-encoding. Because string writing tools provided by core::fmt involve dynamic dispatch and don’t allow reserving capacity in strings buffering the hex and then formatting it is significantly faster.

The buffer has a fixed capacity specified when created. The capacity must be an even number since each byte is encoded as two hex characters.

Examples

let mut encoder = BufEncoder::<4>::new(Case::Lower);
encoder.put_byte(0xab);
assert_eq!(encoder.as_str(), "ab");

The following code doesn’t compile because of odd capacity:

let mut encoder = BufEncoder::<3>::new(Case::Lower);

Implementations

Source

impl<const CAP: usize> BufEncoder<CAP>

pub fn new(case: Case) -> Self

Creates an empty BufEncoder that will encode bytes to hex characters in the given case.

pub fn put_byte(&mut self, byte: u8)

Encodes byte as hex and appends it to the buffer.

Panics

The method panics if the buffer is full.

pub fn put_bytes<I>(&mut self, bytes: I)
where I: IntoIterator, I::Item: Borrow<u8>,

Encodes bytes as hex and appends them to the buffer.

Panics

The method panics if the bytes wouldn’t fit the buffer.

pub fn put_bytes_min<'a>(&mut self, bytes: &'a [u8]) -> &'a [u8]

Encodes as many bytes as fit into the buffer as hex and return the remainder.

This method works just like put_bytes but instead of panicking it returns the unwritten bytes. The method returns an empty slice if all bytes were written

pub fn is_full(&self) -> bool

Returns true if no more bytes can be written into the buffer.

pub fn as_str(&self) -> &str

Returns the written bytes as a hex str.

pub fn clear(&mut self)

Resets the buffer to become empty.

pub fn space_remaining(&self) -> usize

How many bytes can be written to this buffer.

Note that this returns the number of bytes before encoding, not number of hex digits.