HexWriter

Struct HexWriter 

pub struct HexWriter<T> { /* private fields */ }
Available on crate feature std only.
Given a T: fmt::Write, HexWriter implements std::io::Write and writes the source bytes to its inner T as hex characters.

Implementations

Source

impl<T> HexWriter<T>

pub fn new(dest: T, case: Case) -> Self

Creates a HexWriter that writes the source bytes to dest as hex characters in the given case.

Note even though we take ownership of the writer one can also call this with &mut dest.

pub fn into_inner(self) -> T

Consumes this HexWriter returning the inner T.